@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
 our $DATE = '2015-04-25'; # DATE
-our $VERSION = '1.11'; # VERSION
+our $VERSION = '1.12'; # VERSION
 
 use 5.010001;
 use strict;
@@ -135,7 +135,7 @@ our %copts = (
         summary => 'Set output format to json',
         handler => sub {
             my ($go, $val, $r) = @_;
-            $r->{format} = 'json';
+            $r->{format} = (-t STDOUT) ? 'json-pretty' : 'json';
         },
         tags => ['category:output'],
     },
@@ -1266,7 +1266,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.11 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-04-25.
+This document describes version 1.12 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-04-25.
 
 =head1 DESCRIPTION
 
@@ -2145,7 +2145,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Cm
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-CmdLine-Lite>.
 
 =head1 BUGS
 
